function OQPSKSymbols = OQPSK( BPSKSymbols )
% OQPSK - convert BPSK symbols to OQPSK
%
% OQPSK converts a vector of BPSK symbols to OQPSK. The input is assumed to
% be a vector of symbols from the alphabe {1,-1}. Every other symbol is
% phase shifted by 90 degrees. The input is assumed to contain one symbol
% per symbol period.
%
% Input:
%   BPSKSymbols - BPSK encoded information symbols
%
% Output:
%   OQPSKSymbols - OQPSK encode symbols
%
% Example:
%   OQPSKSymbols = OQPSK( BPSKSymbols )

%% BPSK -> OQPSK
% keep odd-numbered samples, phase-shift even numbered samples
OQPSKSymbols          = BPSKSymbols;
% phase shift even samples
OQPSKSymbols(2:2:end) = j*BPSKSymbols(2:2:end); 